@@ -119,7 +119,7 @@ as_year <- function(x, ...) {
 #' @rdname as_year
 #' @export
 as_year.default <- function(x, ...) {
-    stopf("Not implemented for class [%s].", paste(class(x), collapse = ", "))
+    stopf("Not implemented for class [%s].", toString(class(x)))
 }
 
 # -------------------------------------------------------------------------
